"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createVueApolloHook = exports.createReactApolloHook = void 0;
const _utilities_1 = require("../utilities");
const types_generator_1 = require("./types.generator");
const templates_generator_1 = require("./templates.generator");
const _store_1 = require("../store");
const createReactApolloHook = ({ field, functionType, innerFragment, }) => {
    const hasArgs = field.args.length > 0;
    const methodName = field.name;
    const { functionArgsTypeName } = _store_1.SchemaStore.getFunctionFieldArgs(field);
    const { isScalar } = _store_1.SchemaStore.getFieldProps(field);
    const returnedTypeDisplay = types_generator_1.getOneTSTypeDisplay({
        field,
    });
    const typeNameLower = functionType;
    const typeNameUpper = _utilities_1.capitalizeFirstLetter(functionType);
    const Query = templates_generator_1.generateTemplateQuery({
        field,
        innerFragment,
        functionType,
    });
    const TOptions = `{${methodName}: ${returnedTypeDisplay}}${hasArgs ? ', ' + functionArgsTypeName : ''}`;
    let useHookOutput = `return use${typeNameUpper}<${TOptions}>(${typeNameLower}, options);`;
    if (isScalar) {
        return `
    ${field.description ? `/** ${field.description} */` : ''}
    export const use${_utilities_1.capitalizeFirstLetter(field.name)} = (options?: ${typeNameUpper}HookOptions<${TOptions}>) =>  {
      const ${typeNameLower} = ${Query}
      ${useHookOutput}
    },`;
    }
    else {
        return `
    ${field.description ? `/** ${field.description} */` : ''}
    export const use${_utilities_1.capitalizeFirstLetter(field.name)} = (fragment: string | DocumentNode, options?: ${typeNameUpper}HookOptions<${TOptions}>) => {
      const { isString, isFragment, fragmentName } = guessFragmentType(fragment);
      const ${typeNameLower} = ${Query}

      ${useHookOutput}
    }
  ,`;
    }
};
exports.createReactApolloHook = createReactApolloHook;
const createVueApolloHook = ({ field, functionType, innerFragment, }) => {
    const hasArgs = field.args.length > 0;
    const methodName = field.name;
    const { functionArgsTypeName } = _store_1.SchemaStore.getFunctionFieldArgs(field);
    const { isScalar } = _store_1.SchemaStore.getFieldProps(field);
    const returnedTypeDisplay = types_generator_1.getOneTSTypeDisplay({
        field,
    });
    const typeNameLower = functionType;
    const typeNameUpper = _utilities_1.capitalizeFirstLetter(functionType);
    const Query = templates_generator_1.generateTemplateQuery({
        field,
        innerFragment,
        functionType,
    });
    const TOptions = `{${methodName}: ${returnedTypeDisplay}${hasArgs ? ', ' + functionArgsTypeName : ''}}`;
    const TOptionsArgs = `Use${typeNameUpper}Options<${TOptions}>`;
    const vueApolloParams = `${hasArgs
        ? `variables?: ${functionArgsTypeName} | Ref<${functionArgsTypeName}> | ReactiveFunction<${functionArgsTypeName}>,`
        : ''} options?: ${TOptionsArgs} | Ref<${TOptionsArgs}> | ReactiveFunction<${TOptionsArgs}>`;
    let useHookOutput = `return use${typeNameUpper}<${TOptions}>(${typeNameLower}, ${hasArgs ? 'variables,' : 'null,'} options);`;
    if (isScalar) {
        return `
    ${field.description ? `/** ${field.description} */` : ''}
    export const use${_utilities_1.capitalizeFirstLetter(field.name)} = (${vueApolloParams}) =>  {
      const ${typeNameLower} = ${Query}
      ${useHookOutput}
    }`;
    }
    else {
        return `
    ${field.description ? `/** ${field.description} */` : ''}
    export const use${_utilities_1.capitalizeFirstLetter(field.name)} = (fragment: string | DocumentNode, ${vueApolloParams}) => {
      const { isString, isFragment, fragmentName } = guessFragmentType(fragment);
      const ${typeNameLower} = ${Query}

      ${useHookOutput}
    }`;
    }
};
exports.createVueApolloHook = createVueApolloHook;
