"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildTsInterfaceString = exports.getQueriesArgsTSInterfaces = exports.getObjectTSInterfaces = exports.generateQGLArg = exports.generatedTsFields = exports.getOneTSTypeDisplay = exports.generateUnionType = exports.generateEnumType = void 0;
const utilities_1 = require("../utilities");
const parameters_store_1 = require("../store/parameters.store");
const _store_1 = require("../store");
const generateEnumType = (object) => {
    const { prefix, suffix } = parameters_store_1.ParametersStore;
    let ObjectName = object.name;
    const generatedFields = object.enumValues.map((field) => field.name);
    return `${object.description ? `/** ${object.description} */\n` : ''} export enum ${prefix ? prefix : ''}${ObjectName}${suffix ? suffix : ''} {
        ${generatedFields === null || generatedFields === void 0 ? void 0 : generatedFields.map((enumType) => `${utilities_1.capitalizeAllWord(enumType)} = "${enumType}"`).join(',\n')}
  }`;
};
exports.generateEnumType = generateEnumType;
const generateUnionType = (object) => {
    var _a;
    const { prefix, suffix } = parameters_store_1.ParametersStore;
    let ObjectName = object.name;
    return `${object.description ? `/** ${object.description} */\n` : ''} export type ${prefix ? prefix : ''}${ObjectName}${suffix ? suffix : ''} = ${(_a = object.possibleTypes) === null || _a === void 0 ? void 0 : _a.map((type) => type.name).join('|')}`;
};
exports.generateUnionType = generateUnionType;
const getOneTSTypeDisplay = ({ field }) => {
    const { prefix, suffix, listScalars } = parameters_store_1.ParametersStore;
    const { isScalar, typeName, isArray } = _store_1.SchemaStore.getFieldProps(field);
    const returnedName = isScalar
        ? listScalars[typeName]
        : `${prefix ? prefix : ''}${typeName}${suffix ? suffix : ''}`;
    return returnedName + (isArray ? '[]' : '');
};
exports.getOneTSTypeDisplay = getOneTSTypeDisplay;
const generatedTsFields = (fields, isInput) => {
    return fields.map((field) => {
        let propertyName = field.name;
        const { isRequired } = _store_1.SchemaStore.getFieldProps(field);
        const TStypeName = exports.getOneTSTypeDisplay({ field });
        const hasDescription = field.description ||
            ('isDeprecated' in field && field.isDeprecated) ||
            ('defaultValue' in field && field.defaultValue);
        return `${hasDescription
            ? `/** ${'isDeprecated' in field && field.isDeprecated
                ? `@deprecated ${field.deprecationReason}`
                : 'defaultValue' in field && field.defaultValue
                    ? `@default ${field.defaultValue}`
                    : ''}${field.description ? field.description : ''}*/\n`
            : ''} ${propertyName}${isRequired ? '' : isInput ? '?' : ''}: ${isRequired || isInput ? TStypeName : `Maybe<${TStypeName}>`};`;
    });
};
exports.generatedTsFields = generatedTsFields;
const generateQGLArg = (field) => {
    const { isArray, isArrayRequired, isRequired, typeName } = _store_1.SchemaStore.getFieldProps(field);
    return `${isArray ? '[' : ''}${typeName}${isArrayRequired ? '!' : ''}${isArray ? ']' : ''}${isRequired ? '!' : ''}`;
};
exports.generateQGLArg = generateQGLArg;
const getObjectTSInterfaces = (object, isInput) => {
    let fields = isInput ? object.inputFields : object.fields;
    const generatedFields = exports.generatedTsFields(fields, isInput);
    return exports.buildTsInterfaceString(object, generatedFields);
};
exports.getObjectTSInterfaces = getObjectTSInterfaces;
const getQueriesArgsTSInterfaces = (object) => {
    const generatedFields = exports.generatedTsFields(object.args, true);
    return exports.buildTsInterfaceString(object, generatedFields, 'Args');
};
exports.getQueriesArgsTSInterfaces = getQueriesArgsTSInterfaces;
const buildTsInterfaceString = (type, fields, additionalSuffix) => {
    const { prefix, suffix } = parameters_store_1.ParametersStore;
    return `${type.description ? `/** ${type.description} */\n` : ''} export interface ${prefix ? prefix : ''}${type.name}${suffix ? suffix : ''}${additionalSuffix ? additionalSuffix : ''} {
    ${fields.join('\n')}
  }
`;
};
exports.buildTsInterfaceString = buildTsInterfaceString;
